function mphinputmatrix(model, ME, soltag, solfeature, varargin)
% MPHINPUTMATRIX Add matrix system for linear solver.
%  
%   MPHINPUTMATRIX(MODEL,STR,SOLTAG,SOLTYPETAG) adds the system matrices 
%   and vectors stored in the MATLAB structure STR to the model object 
%   MODEL. The system matrices is associated to the linear solver 
%   configuration defined with the tag SOLTAG and solved with the solver 
%   defined with the tag SOLTYPETAG.
%   SOLTYPETAG can only be one of the following solver type: 
%   Stationary, Eigenvalue, Time.
% 
%   A valid structure for a stationary solver includes the following 
%   fields:
%   Field name          Description
%   -----------------------------------------------------------------------
%   'K'                 Stiffness matrix
%   'L'                 Load vector
%   'M'                 Constraint vector
%   'N'                 Constraint Jacobian
%
%   A valid structure for a time dependent/eigenvalue solver includes the
%   fields:
%   Field name          Description
%   -----------------------------------------------------------------------
%   'K'                 Stiffness matrix
%   'L'                 Load vector
%   'M'                 Constraint vector
%   'N'                 Constraint Jacobian
%   'D'                 Damping matrix
%   'E'                 Mass matrix
%
%   There is also the possibility to include the constraint force Jacobian 
%   vector 'NF'.
%   Once the matrix system is loaded in the model, the solver configuration 
%   is set ready to run.
%   Note that the system matrices are not stored in the model when it is 
%   saved as a MPH-file or loaded into the COMSOL Desktop.
%
%
%   Example:
%     % Load model_tutorial_llmatlab.mph:
%     model = mphopen('model_tutorial_llmatlab');
%     % Add a stationary study step and a solver configuration:
%     std1 = model.study.create('std1');
%     std1.feature.create('stat', 'Stationary');
%     sol1 = model.sol.create('sol1');
%     sol1.study('std1');
%     % Set-up the solver configuration for a stationary problem:
%     st1 = sol1.feature.create('st1', 'StudyStep');
%     st1.set('studystep', 'stat');
%     sol1.feature.create('v1', 'Variables');
%     sol1.feature.create('s1', 'Stationary');
%
%     % Extract the linear stationary matrix system in MATLAB:
%     str = mphmatrix(model,'sol1','out',{'K','L','M','N'},...
%        'initmethod','sol','initsol','zero');
%     % Change the linear system by scaling the stiffness matrix:
%     str.K = str.K*0.5;
%     % Insert the system matrix back to the model:
%     mphinputmatrix(model,str,'sol1','s1')
%     % Run the solver configuration:
%     model.sol('sol1').runAll;
%
%   See also: mphmatrix, mphxmeshinfo

%   Copyright 2012-2017 COMSOL
